.. _exceptions_module:

:mod:`kazoo.exceptions`
-----------------------

.. automodule:: kazoo.exceptions

Public API
++++++++++

.. autoexception:: KazooException

.. autoexception:: ZookeeperError

.. autoexception:: AuthFailedError

.. autoexception:: BadVersionError

.. autoexception:: ConfigurationError

.. autoexception:: InvalidACLError

.. autoexception:: LockTimeout

.. autoexception:: NoChildrenForEphemeralsError

.. autoexception:: NodeExistsError

.. autoexception:: NoNodeError

.. autoexception:: NotEmptyError

Private API
+++++++++++

.. autoexception:: APIError

.. autoexception:: BadArgumentsError

.. autoexception:: CancelledError

.. autoexception:: ConnectionDropped

.. autoexception:: ConnectionClosedError

.. autoexception:: ConnectionLoss

.. autoexception:: DataInconsistency

.. autoexception:: MarshallingError

.. autoexception:: NoAuthError

.. autoexception:: NotReadOnlyCallError

.. autoexception:: InvalidCallbackError

.. autoexception:: OperationTimeoutError

.. autoexception:: RolledBackError

.. autoexception:: RuntimeInconsistency

.. autoexception:: SessionExpiredError

.. autoexception:: SessionMovedError

.. autoexception:: SystemZookeeperError

.. autoexception:: UnimplementedError

.. autoexception:: WriterNotClosedException

.. autoexception:: ZookeeperStoppedError
